/*
	This sample demonstrates the way to create a simple EventService object and
	use it to send an event to the Correlator. 
	
	Requirement:
	
	The SimpleEvent.mon must be injected to the correlator before running this 
	example.  The SimpleEvent.mon simply log the message to the Correlator
	standard output.  You'll see a message similar to this in the Correlator
	console when you run this example:
	
	<date> 15:43:10.360 CRIT SimpleEventMon [0] *** SimpleEvent("hi there") received ***
	
	$Copyright(c) 2010, 2012, 2013 Progress Software Corporation. All Rights Reserved.$ 
	$Copyright (c) 2013, 2015 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$ 
	Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 

*/

using System;

using Apama;
using Apama.Util;
using Apama.Event;
using Apama.Services.Event;

public class EventServiceSample {
	private static readonly Logger logger = Logger.GetLogger(typeof(EventServiceSample));
	
	/// <summary>
	///Sends the SimpleEvent("hi there") event to the correlator.
	/// </summary>
	public void RunSample(string host, int port) {

		try {
			
			// get a IEventService instance from the EventServiceFactory
			using (IEventService eventService = EventServiceFactory.CreateEventService(host, port, "EventServiceSample"))
			{
				// create the simpleEvent object
				Event simpleEvent = new Event("SimpleEvent(\"hi there\")");
				
				// send it
				eventService.SendEvent(simpleEvent);
				
				Console.WriteLine("SimpleEvent(hi there) sent...");  
				Console.Write("\t Please check Correlator console for the string ");
				Console.Write("\t *** SimpleEvent(\"hi there\") received ***");
			}
		} catch (EngineException e) {
			logger.Error("Exception caught: ", e);
		}
	}
	
	public static void Main(string[] args) {
		if ((args.Length == 2) && (int.Parse(args[1]) > 0))
		{
			string host = args[0];
			int port = int.Parse(args[1]);
			new EventServiceSample().RunSample(host, port);
		}
		else
		{
			Console.WriteLine("Usage: EventServiceSample.exe <host> <port>");
		}
	}

} 
